summaryrefslogtreecommitdiffstats
path: root/kmail/headerlistquicksearch.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:50 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:50 -0600
commit9cc13dcbb01a96c9e60a07ca63c61d24b374f50d (patch)
treeab537a329b9613e11dce8195761f93ffe82aed24 /kmail/headerlistquicksearch.h
parent3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12 (diff)
downloadtdepim-9cc13dcbb01a96c9e60a07ca63c61d24b374f50d.tar.gz
tdepim-9cc13dcbb01a96c9e60a07ca63c61d24b374f50d.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12.
Diffstat (limited to 'kmail/headerlistquicksearch.h')
-rw-r--r--kmail/headerlistquicksearch.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmail/headerlistquicksearch.h b/kmail/headerlistquicksearch.h
index 0e3c4c9d..e0589c7d 100644
--- a/kmail/headerlistquicksearch.h
+++ b/kmail/headerlistquicksearch.h
@@ -31,7 +31,7 @@
#ifndef KMAILHEADERLISTQUICKSEARCH_H
#define KMAILHEADERLISTQUICKSEARCH_H
-#include "kmmsgbase.h" // for KMMsgStatus
+#include "kmmsgbase.h" // for KMMsgtqStatus
#include "kmsearchpattern.h"
#include <klistviewsearchline.h>
#include <tqvaluevector.h>
@@ -67,7 +67,7 @@ public:
/**
* Returns the currently selected status filter.
*/
- int currenStatus() const;
+ int currentqStatus() const;
public slots:
void reset();
@@ -78,22 +78,22 @@ signals:
protected:
/**
* checks whether @param item contains the search string and has the status
* currently in mStatus
*/
virtual bool itemMatches(const TQListViewItem *item, const TQString &s) const;
private slots:
/**
* cache the status in mStatus so as to avoid having to do the comparatively
* expensive string comparison for each item in itemMatches
*/
void sloStatusChanged( int index );
private:
/** Helper method for the filling of the status combo. */
- void inserStatus(KMail::StatusValueTypes which);
+ void insertqStatus(KMail::StatusValueTypes which);
TQComboBox *mStatusCombo;
- KMMsgStatus mStatus;
+ KMMsgtqStatus mtqStatus;
TQValueVector<TQString> statusList;
mutable TQString mCurrentSearchTerm;
};
@@ -78,22 +78,22 @@ signals:
/**
* checks whether @param item contains the search string and has the status
- * currently in mStatus
+ * currently in mtqStatus
*/
virtual bool itemMatches(const TQListViewItem *item, const TQString &s) const;
@@ -78,22 +78,22 @@ signals:
private slots:
/**
- * cache the status in mStatus so as to avoid having to do the comparatively
+ * cache the status in mtqStatus so as to avoid having to do the comparatively
* expensive string comparison for each item in itemMatches
*/